[Qa-jenkins-scm] [jenkins.debian.net] 01/02: reproducible Debian: add 10 new armhf builder jobs, thanks to Vagrant for those 3 new build nodes

Holger Levsen holger at layer-acht.org
Fri Jun 2 12:24:45 UTC 2017


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit 0730c41a90eec6d140ccc150d6c19dc03b105390
Author: Holger Levsen <holger at layer-acht.org>
Date:   Fri Jun 2 13:59:55 2017 +0200

    reproducible Debian: add 10 new armhf builder jobs, thanks to Vagrant for those 3 new build nodes
    
    Signed-off-by: Holger Levsen <holger at layer-acht.org>
---
 README                            |  2 +-
 bin/reproducible_build_service.sh | 36 +++++++++++++++++++++++++-----------
 2 files changed, 26 insertions(+), 12 deletions(-)

diff --git a/README b/README
index e99c2ad..0285489 100644
--- a/README
+++ b/README
@@ -135,7 +135,7 @@ Installation tests inside chroot environments.
 
 * The (current) purpose of https://tests.reproducible-builds.org is to show the potential of reproducible builds for Debian - and six other projects currently. This is research, showing what could (and should) be done... check https://wiki.debian.org/ReproducibleBuilds for the real status of the project for Debian!
 
-* For Debian, three suites, 'testing', 'unstable' and 'experimental', are tested on four architectures: 'amd64', 'i386', 'arm64' and 'armhf'. The tests are done using 'pbuilder' through several concurrent workers: 40 for 'amd64', 24 for 'i386', 32 for 'arm64' and 66 for 'armhf', which are each constantly testing packages and saving the results of these tests. There's a single link:https://anonscm.debian.org/git/qa/jenkins.debian.net.git/tree/bin/reproducible_build_service.sh[systemd serv [...]
+* For Debian, three suites, 'testing', 'unstable' and 'experimental', are tested on four architectures: 'amd64', 'i386', 'arm64' and 'armhf'. The tests are done using 'pbuilder' through several concurrent workers: 40 for 'amd64', 24 for 'i386', 32 for 'arm64' and 76 for 'armhf', which are each constantly testing packages and saving the results of these tests. There's a single link:https://anonscm.debian.org/git/qa/jenkins.debian.net.git/tree/bin/reproducible_build_service.sh[systemd serv [...]
 
 * These builds on remote nodes run on very different hardware:
 ** for 'amd64' we are using four virtual machines, profitbricks-build(1+5+11+15)-amd64, which have 15 or 16 cores and 48gb ram each. These nodes are sponsored by link:https://jenkins.debian.net/userContent/thanks.html[Profitbricks].
diff --git a/bin/reproducible_build_service.sh b/bin/reproducible_build_service.sh
index 5690606..3ef249a 100755
--- a/bin/reproducible_build_service.sh
+++ b/bin/reproducible_build_service.sh
@@ -116,12 +116,16 @@ choose_nodes() {
                 arm64_31)       NODE1=codethink-sled14-arm64	NODE2=codethink-sled11-arm64 ;;
                 arm64_32)       NODE1=codethink-sled13-arm64	NODE2=codethink-sled14-arm64 ;;
 		# to choose new armhf jobs:
 	        #       for i in cb3a hb0 rpi2b rpi2c wbd0 bpi0 bbx15 cbxi4pro0 ff2a ff2b jtk1a odxu4 odxu4b odxu4c odu3a opi2a opi2b opi2c p64b p64c wbq0 cbxi4a cbxi4b ff4a ; do echo "$i: " ; grep NODE1 bin/reproducible_build_service.sh|grep armhf|grep $i-armhf ; done
 	        #       8 jobs for quad-cores with 4 gb ram
 	        #       6 jobs for octo-cores with 2 gb ram
+	        #       6 jobs for hexa-cores with 2 gb ram
 	        #       6 jobs for quad-cores with 2 gb ram
 	        #       3 jobs for dual-cores with 1 gb ram
 	        #       3 jobs for quad-cores with 1 gb ram
+		#
+		# Don't forget to update README with the number of builders…!
+		#
                 armhf_1)	NODE1=bbx15-armhf-rb		NODE2=odxu4-armhf-rb ;;
                 armhf_2)	NODE1=wbq0-armhf-rb		NODE2=p64c-armhf-rb ;;
                 armhf_3)	NODE1=hb0-armhf-rb		NODE2=p64b-armhf-rb ;;
@@ -178,16 +182,26 @@ choose_nodes() {
                 armhf_54)	NODE1=odu3a-armhf-rb		NODE2=opi2c-armhf-rb ;;
                 armhf_55)	NODE1=opi2c-armhf-rb		NODE2=odu3a-armhf-rb ;;
                 armhf_56)	NODE1=odu3a-armhf-rb		NODE2=ff2a-armhf-rb ;;
-                armhf_57)	NODE1=opi2c-armhf-rb		NODE2=ff2a-armhf-rb ;;
-                armhf_58)	NODE1=cbxi4a-armhf-rb		NODE2=p64b-armhf-rb ;;
-                armhf_59)	NODE1=jtk1a-armhf-rb		NODE2=p64c-armhf-rb ;;
-                armhf_60)	NODE1=cbxi4b-armhf-rb		NODE2=opi2a-armhf-rb ;;
-                armhf_61)	NODE1=p64c-armhf-rb		NODE2=opi2a-armhf-rb ;;
-                armhf_62)	NODE1=p64b-armhf-rb		NODE2=opi2a-armhf-rb ;;
-                armhf_63)	NODE1=p64b-armhf-rb		NODE2=ff4a-armhf-rb ;;
-                armhf_64)	NODE1=p64c-armhf-rb		NODE2=bbx15-armhf-rb ;;
-                armhf_65)	NODE1=p64b-armhf-rb		NODE2=cbxi4pro0-armhf-rb ;;
-                armhf_66)	NODE1=p64c-armhf-rb		NODE2=odxu4-armhf-rb ;;
+                armhf_57)	NODE1=opi2c-armhf-rb		NODE2=ff64a-armhf-rb ;;
+                armhf_58)	NODE1=cbxi4a-armhf-rb		NODE2=ff64a-armhf-rb ;;
+                armhf_59)	NODE1=jtk1a-armhf-rb		NODE2=ff64a-armhf-rb ;;
+                armhf_60)	NODE1=cbxi4b-armhf-rb		NODE2=jtx1a-armhf-rb ;;
+                armhf_61)	NODE1=p64c-armhf-rb		NODE2=jtx1a-armhf-rb ;;
+                armhf_62)	NODE1=p64b-armhf-rb		NODE2=jtx1a-armhf-rb ;;
+                armhf_63)	NODE1=p64b-armhf-rb		NODE2=jtx1a-armhf-rb ;;
+                armhf_64)	NODE1=p64c-armhf-rb		NODE2=odc2a-armhf-rb ;;
+                armhf_65)	NODE1=p64b-armhf-rb		NODE2=odc2a-armhf-rb ;;
+                armhf_66)	NODE1=p64c-armhf-rb		NODE2=odc2a-armhf-rb ;;
+                armhf_67)	NODE1=ff64a-armhf-rb		NODE2=ff2a-armhf-rb ;;
+                armhf_68)	NODE1=ff64a-armhf-rb		NODE2=p64b-armhf-rb ;;
+                armhf_69)	NODE1=ff64a-armhf-rb		NODE2=p64c-armhf-rb ;;
+                armhf_70)	NODE1=jtx1a-armhf-rb		NODE2=opi2a-armhf-rb ;;
+                armhf_71)	NODE1=jtx1a-armhf-rb		NODE2=opi2a-armhf-rb ;;
+                armhf_72)	NODE1=jtx1a-armhf-rb		NODE2=opi2a-armhf-rb ;;
+                armhf_73)	NODE1=jtx1a-armhf-rb		NODE2=ff4a-armhf-rb ;;
+                armhf_74)	NODE1=odc2a-armhf-rb		NODE2=bbx15-armhf-rb ;;
+                armhf_75)	NODE1=odc2a-armhf-rb		NODE2=cbxi4pro0-armhf-rb ;;
+                armhf_76)	NODE1=odc2a-armhf-rb		NODE2=odxu4-armhf-rb ;;
 
 		*)		echo "Sleeping 60min"
 				sleep 60m
@@ -116,12 +116,16 @@ choose_nodes() {
                 arm64_32)       NODE1=codethink-sled13-arm64	NODE2=codethink-sled14-arm64 ;;
 		# to choose new armhf jobs:
-	        #       for i in cb3a hb0 rpi2b rpi2c wbd0 bpi0 bbx15 cbxi4pro0 ff2a ff2b jtk1a odxu4 odxu4b odxu4c odu3a opi2a opi2b opi2c p64b p64c wbq0 cbxi4a cbxi4b ff4a ; do echo "$i: " ; grep NODE1 bin/reproducible_build_service.sh|grep armhf|grep $i-armhf ; done
+	        #       for i in cb3a hb0 rpi2b rpi2c wbd0 bpi0        bbx15 cbxi4pro0 ff2a ff2b ff64a jtk1a odc2a odxu4 odxu4b odxu4c odu3a opi2a opi2b opi2c p64b p64c wbq0        cbxi4a cbxi4b ff4a jtx1a ; do echo "$i: " ; grep NODE1 bin/reproducible_build_service.sh|grep armhf|grep $i-armhf ; done
 	        #       8 jobs for quad-cores with 4 gb ram
 	        #       6 jobs for octo-cores with 2 gb ram

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list